==> qt-creator-1.2.90-src.zip: qt-creator-1.2.90-src/src/plugins/qt4projectmanager/gettingstartedwelcomepage.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://qt.nokia.com/contact.
**
**************************************************************************/

#ifndef GETTINGSTARTEDWELCOMEPLUGIN_H
#define GETTINGSTARTEDWELCOMEPLUGIN_H

#include <extensionsystem/iwelcomepage.h>

namespace Qt4ProjectManager {
namespace Internal {

class GettingStartedWelcomePageWidget;

class GettingStartedWelcomePage : public ExtensionSystem::IWelcomePage
{
    Q_OBJECT
public:
    GettingStartedWelcomePage();

    QWidget *page();
    QString title() const { return tr("Getting Started");}
    int priority() const { return 10; }

private:
    GettingStartedWelcomePageWidget *m_page;
};

} // namespace Internal
} // namespace Qt4ProjectManager

#endif // GETTINGSTARTEDWELCOMEPLUGIN_H

==> qt-creator-2.0.0-rc1-src.zip: qt-creator-2.0.0-rc1-src/src/plugins/qt4projectmanager/gettingstartedwelcomepage.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://qt.nokia.com/contact.
**
**************************************************************************/

#ifndef GETTINGSTARTEDWELCOMEPLUGIN_H
#define GETTINGSTARTEDWELCOMEPLUGIN_H

#include <utils/iwelcomepage.h>

namespace Qt4ProjectManager {
namespace Internal {

class GettingStartedWelcomePageWidget;

class GettingStartedWelcomePage : public Utils::IWelcomePage
{
    Q_OBJECT
public:
    GettingStartedWelcomePage();

    QWidget *page();
    QString title() const { return tr("Getting Started");}
    int priority() const { return 10; }

public slots:
    void updateExamples(const QString &examplePath,
                        const QString &demosPath,
                        const QString &sourcePath);

private:
    GettingStartedWelcomePageWidget *m_page;
};

} // namespace Internal
} // namespace Qt4ProjectManager

#endif // GETTINGSTARTEDWELCOMEPLUGIN_H
